searchData={"items":[{"type":"module","title":"OpenTelemetry","doc":"An [OpenTelemetry](https://opentelemetry.io) Trace consists of 1 or more Spans that either have a\nparent/child relationship or are linked together through a Link. Each Span has a TraceId (`t:trace_id/0`),\nSpanId (`t:span_id/0`), and a start and end time in nanoseconds.\n\nThis module provides declaration of the types used throughout the library, as well as functions for\nbuilding the additional pieces of a span that are optional. Each item can be attached to individual\nSpan using the functions in `OpenTelemetry.Span` module.","ref":"OpenTelemetry.html"},{"type":"module","title":"Example - OpenTelemetry","doc":"require OpenTelemetry.Tracer, as: Tracer\n\n    Tracer.with_span \"some-span\" do\n      event = OpenTelemetry.event(\"ecto.query\", query: query, total_time: total_time)\n      Tracer.add_events([event])\n    end","ref":"OpenTelemetry.html#module-example"},{"type":"function","title":"OpenTelemetry.convert_timestamp/2","doc":"Convert a native monotonic timestamp to POSIX time of any `t::erlang.time_unit/0`.\nMeaning the time since Epoch. Epoch is defined to be 00:00:00 UTC, 1970-01-01.","ref":"OpenTelemetry.html#convert_timestamp/2"},{"type":"function","title":"OpenTelemetry.event/2","doc":"Creates a `t:event/0`.","ref":"OpenTelemetry.html#event/2"},{"type":"function","title":"OpenTelemetry.event/3","doc":"Creates a `t:event/0`.","ref":"OpenTelemetry.html#event/3"},{"type":"function","title":"OpenTelemetry.events/1","doc":"Creates a list of `t:event/0` items.","ref":"OpenTelemetry.html#events/1"},{"type":"function","title":"OpenTelemetry.get_tracer/1","doc":"","ref":"OpenTelemetry.html#get_tracer/1"},{"type":"function","title":"OpenTelemetry.get_tracer/3","doc":"","ref":"OpenTelemetry.html#get_tracer/3"},{"type":"function","title":"OpenTelemetry.link/1","doc":"Creates a `t:link/0` from a `t:span_ctx/0`.","ref":"OpenTelemetry.html#link/1"},{"type":"function","title":"OpenTelemetry.link/2","doc":"Creates a `t:link/0` from a `t:span_ctx/0` and list of `t:attributes_map/0`.","ref":"OpenTelemetry.html#link/2"},{"type":"function","title":"OpenTelemetry.link/4","doc":"Creates a `t:link/0`.","ref":"OpenTelemetry.html#link/4"},{"type":"function","title":"OpenTelemetry.links/1","doc":"Creates a list of `t:link/0` from a list of 4-tuples.","ref":"OpenTelemetry.html#links/1"},{"type":"function","title":"OpenTelemetry.set_default_tracer/1","doc":"","ref":"OpenTelemetry.html#set_default_tracer/1"},{"type":"function","title":"OpenTelemetry.status/1","doc":"Creates a Status with an empty description.","ref":"OpenTelemetry.html#status/1"},{"type":"function","title":"OpenTelemetry.status/2","doc":"Creates a Status.","ref":"OpenTelemetry.html#status/2"},{"type":"function","title":"OpenTelemetry.timestamp/0","doc":"A monotonically increasing time provided by the Erlang runtime system in the native time unit.\nThis value is the most accurate and precise timestamp available from the Erlang runtime and\nshould be used for finding durations or any timestamp that can be converted to a system\ntime before being sent to another system.\n\nUse `convert_timestamp/2` or `timestamp_to_nano/1` to convert a native monotonic time to a\nsystem time of either nanoseconds or another unit.\n\nUsing these functions allows timestamps to be accurate, used for duration and be exportable\nas POSIX time when needed.","ref":"OpenTelemetry.html#timestamp/0"},{"type":"function","title":"OpenTelemetry.timestamp_to_nano/1","doc":"Convert a native monotonic timestamp to nanosecond POSIX time. Meaning the time since Epoch.\nEpoch is defined to be 00:00:00 UTC, 1970-01-01.","ref":"OpenTelemetry.html#timestamp_to_nano/1"},{"type":"type","title":"OpenTelemetry.attribute_key/0","doc":"","ref":"OpenTelemetry.html#t:attribute_key/0"},{"type":"type","title":"OpenTelemetry.attribute_value/0","doc":"","ref":"OpenTelemetry.html#t:attribute_value/0"},{"type":"type","title":"OpenTelemetry.attributes_map/0","doc":"Attributes are a collection of key/value pairs. The value can be a string,\nan integer, a double or the boolean values `true` or `false`. Note, global attributes\nlike server name can be set using the resource API.\n\nExamples of attributes:\n\n    [{\"/http/user_agent\" \"Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/71.0.3578.98 Safari/537.36\"}\n     {\"/http/server_latency\", 300}\n     {\"abc.com/myattribute\", True}\n     {\"abc.com/score\", 10.239}]","ref":"OpenTelemetry.html#t:attributes_map/0"},{"type":"type","title":"OpenTelemetry.event/0","doc":"An Event is a time-stamped annotation of the span, consisting of user-supplied\ntext description and key-value pairs.","ref":"OpenTelemetry.html#t:event/0"},{"type":"type","title":"OpenTelemetry.event_name/0","doc":"","ref":"OpenTelemetry.html#t:event_name/0"},{"type":"type","title":"OpenTelemetry.link/0","doc":"A Link is a pointer from the current span to another span in the same trace or in a\ndifferent trace. For example, this can be used in batching operations,\nwhere a single batch handler processes multiple requests from different\ntraces or when the handler receives a request from a different project.","ref":"OpenTelemetry.html#t:link/0"},{"type":"type","title":"OpenTelemetry.span/0","doc":"Span represents a single operation within a trace. Spans can be\nnested to form a trace tree. Spans may also be linked to other spans\nfrom the same or different trace and form graphs. Often, a trace\ncontains a root span that describes the end-to-end latency, and one\nor more subspans for its sub-operations. A trace can also contain\nmultiple root spans, or none at all. Spans do not need to be\ncontiguous - there may be gaps or overlaps between spans in a trace.","ref":"OpenTelemetry.html#t:span/0"},{"type":"type","title":"OpenTelemetry.span_ctx/0","doc":"A SpanContext represents the portion of a Span needed to do operations on a\nSpan. Within a process it acts as a key for looking up and modifying the\nactual Span. It is also what is serialized and propagated across process\nboundaries.","ref":"OpenTelemetry.html#t:span_ctx/0"},{"type":"type","title":"OpenTelemetry.span_id/0","doc":"SpanId is a unique identifier for a span within a trace, assigned when the span\nis created. The ID is an 8-byte array. An ID with all zeroes is considered\ninvalid.","ref":"OpenTelemetry.html#t:span_id/0"},{"type":"type","title":"OpenTelemetry.span_kind/0","doc":"","ref":"OpenTelemetry.html#t:span_kind/0"},{"type":"type","title":"OpenTelemetry.span_name/0","doc":"","ref":"OpenTelemetry.html#t:span_name/0"},{"type":"type","title":"OpenTelemetry.status/0","doc":"An optional final status for this span. Semantically when Status\nwasn't set it means span ended without errors and assume `:unset`.\n\nApplication developers may set the status as `:ok` when the operation\nhas been validated to have completed successfully, or `:error` when\nthe operation contains an error.","ref":"OpenTelemetry.html#t:status/0"},{"type":"type","title":"OpenTelemetry.status_code/0","doc":"","ref":"OpenTelemetry.html#t:status_code/0"},{"type":"type","title":"OpenTelemetry.trace_id/0","doc":"TraceId is a unique identifier for a trace. All spans from the same trace share\nthe same `trace_id`. The ID is a 16-byte array. An ID with all zeroes\nis considered invalid.","ref":"OpenTelemetry.html#t:trace_id/0"},{"type":"type","title":"OpenTelemetry.tracestate/0","doc":"Tracestate represents tracing-system specific context in a list of key-value pairs.\nTracestate allows different vendors propagate additional information and\ninter-operate with their legacy Id formats.\n\nIt is a tracestate in the [w3c-trace-context format](https://www.w3.org/TR/trace-context/#tracestate-header).\nSee also [https://github.com/w3c/distributed-tracing](https://github.com/w3c/distributed-tracing)\nfor more details about this field.","ref":"OpenTelemetry.html#t:tracestate/0"},{"type":"module","title":"OpenTelemetry.Baggage","doc":"Baggage is used to annotate telemetry, adding context and information to\nmetrics, traces, and logs. It is represented by a set of name/value pairs\ndescribing user-defined properties.","ref":"OpenTelemetry.Baggage.html"},{"type":"function","title":"OpenTelemetry.Baggage.clear/0","doc":"","ref":"OpenTelemetry.Baggage.html#clear/0"},{"type":"function","title":"OpenTelemetry.Baggage.clear/1","doc":"","ref":"OpenTelemetry.Baggage.html#clear/1"},{"type":"function","title":"OpenTelemetry.Baggage.get_all/0","doc":"","ref":"OpenTelemetry.Baggage.html#get_all/0"},{"type":"function","title":"OpenTelemetry.Baggage.get_all/1","doc":"","ref":"OpenTelemetry.Baggage.html#get_all/1"},{"type":"function","title":"OpenTelemetry.Baggage.set/1","doc":"","ref":"OpenTelemetry.Baggage.html#set/1"},{"type":"function","title":"OpenTelemetry.Baggage.set/2","doc":"","ref":"OpenTelemetry.Baggage.html#set/2"},{"type":"function","title":"OpenTelemetry.Baggage.set/3","doc":"","ref":"OpenTelemetry.Baggage.html#set/3"},{"type":"function","title":"OpenTelemetry.Baggage.set/4","doc":"","ref":"OpenTelemetry.Baggage.html#set/4"},{"type":"module","title":"OpenTelemetry.Ctx","doc":"Ctx is responsible for propagating values within a process that are associated\nwith a particular Trace or set of Baggage. `OpenTelemetry.Tracer` and\n`OpenTelemetry.Baggage` handle updating the Context.","ref":"OpenTelemetry.Ctx.html"},{"type":"function","title":"OpenTelemetry.Ctx.attach/1","doc":"","ref":"OpenTelemetry.Ctx.html#attach/1"},{"type":"function","title":"OpenTelemetry.Ctx.clear/0","doc":"","ref":"OpenTelemetry.Ctx.html#clear/0"},{"type":"function","title":"OpenTelemetry.Ctx.detach/1","doc":"","ref":"OpenTelemetry.Ctx.html#detach/1"},{"type":"function","title":"OpenTelemetry.Ctx.get_current/0","doc":"","ref":"OpenTelemetry.Ctx.html#get_current/0"},{"type":"function","title":"OpenTelemetry.Ctx.get_value/2","doc":"","ref":"OpenTelemetry.Ctx.html#get_value/2"},{"type":"function","title":"OpenTelemetry.Ctx.get_value/3","doc":"","ref":"OpenTelemetry.Ctx.html#get_value/3"},{"type":"function","title":"OpenTelemetry.Ctx.new/0","doc":"","ref":"OpenTelemetry.Ctx.html#new/0"},{"type":"function","title":"OpenTelemetry.Ctx.remove/1","doc":"","ref":"OpenTelemetry.Ctx.html#remove/1"},{"type":"function","title":"OpenTelemetry.Ctx.set_value/2","doc":"","ref":"OpenTelemetry.Ctx.html#set_value/2"},{"type":"function","title":"OpenTelemetry.Ctx.set_value/3","doc":"","ref":"OpenTelemetry.Ctx.html#set_value/3"},{"type":"type","title":"OpenTelemetry.Ctx.t/0","doc":"","ref":"OpenTelemetry.Ctx.html#t:t/0"},{"type":"module","title":"OpenTelemetry.Span","doc":"This module contains macros for Span operations that update the active current Span in the current process.\nAn example of creating an Event and adding it to the current Span:\n\n    require OpenTelemetry.Tracer, as: Tracer\n    require OpenTelemetry.Span, as: Span\n\n    span_ctx = Tracer.start_span(\"some-span\")\n    ...\n    Span.add_event(span_ctx, \"ecto.query\", query: query, total_time: total_time)\n    ...\n    Span.end_span(span_ctx)\n\nA Span represents a single operation within a trace. Spans can be nested to form a trace tree.\nEach trace contains a root span, which typically describes the end-to-end latency and, optionally,\none or more sub-spans for its sub-operations.\n\nSpans encapsulate:\n\n- The span name\n- An immutable SpanContext (`t:OpenTelemetry.span_ctx/0`) that uniquely identifies the Span\n- A parent Span in the form of a Span (`t:OpenTelemetry.span/0`), SpanContext (`t:OpenTelemetry.span_ctx/0`), or `undefined`\n- A start timestamp\n- An end timestamp\n- An ordered mapping of Attributes (`t:OpenTelemetry.attributes_map/0`)\n- A list of Links to other Spans (`t:OpenTelemetry.link/0`)\n- A list of timestamped Events (`t:OpenTelemetry.event/0`)\n- A Status (`t:OpenTelemetry.status/0`)","ref":"OpenTelemetry.Span.html"},{"type":"function","title":"OpenTelemetry.Span.add_event/3","doc":"Add an event to the currently active Span.","ref":"OpenTelemetry.Span.html#add_event/3"},{"type":"function","title":"OpenTelemetry.Span.add_events/2","doc":"Add a list of events to the currently active Span.","ref":"OpenTelemetry.Span.html#add_events/2"},{"type":"function","title":"OpenTelemetry.Span.end_span/1","doc":"End the Span. Sets the end timestamp for the currently active Span. This has no effect on any\nchild Spans that may exist of this Span.\n\nThe Span Context is returned with `is_recording` set to `false`.","ref":"OpenTelemetry.Span.html#end_span/1"},{"type":"function","title":"OpenTelemetry.Span.end_span/2","doc":"End the Span. Sets the end timestamp for the currently active Span using the passed in timestamp if valid, current timestamp otherwise. This has no effect on any\nchild Spans that may exist of this Span.\n\nThe Span Context is returned with `is_recording` set to `false`.","ref":"OpenTelemetry.Span.html#end_span/2"},{"type":"function","title":"OpenTelemetry.Span.hex_span_id/1","doc":"Get the lowercase hex encoded span ID.","ref":"OpenTelemetry.Span.html#hex_span_id/1"},{"type":"function","title":"OpenTelemetry.Span.hex_trace_id/1","doc":"Get the lowercase hex encoded trace ID.","ref":"OpenTelemetry.Span.html#hex_trace_id/1"},{"type":"function","title":"OpenTelemetry.Span.is_recording/1","doc":"","ref":"OpenTelemetry.Span.html#is_recording/1"},{"type":"function","title":"OpenTelemetry.Span.is_valid/1","doc":"","ref":"OpenTelemetry.Span.html#is_valid/1"},{"type":"function","title":"OpenTelemetry.Span.record_exception/4","doc":"Record an exception as an event, following the semantics convetions for exceptions.\n\nIf trace is not provided, the stacktrace is retrieved from `Process.info/2`","ref":"OpenTelemetry.Span.html#record_exception/4"},{"type":"function","title":"OpenTelemetry.Span.set_attribute/3","doc":"Set an attribute with key and value on the currently active Span.","ref":"OpenTelemetry.Span.html#set_attribute/3"},{"type":"function","title":"OpenTelemetry.Span.set_attributes/2","doc":"Add a list of attributes to the currently active Span.","ref":"OpenTelemetry.Span.html#set_attributes/2"},{"type":"function","title":"OpenTelemetry.Span.set_status/2","doc":"Sets the Status of the currently active Span.\n\nIf used, this will override the default Span Status, which is `:unset`.\nValid statuses are `:ok`, or `:error`. Calling this will also set the\n`status_code` attribute to `1`(`:ok`), or `2`(`:error`).","ref":"OpenTelemetry.Span.html#set_status/2"},{"type":"function","title":"OpenTelemetry.Span.span_id/1","doc":"Get the SpanId of a Span.","ref":"OpenTelemetry.Span.html#span_id/1"},{"type":"function","title":"OpenTelemetry.Span.trace_id/1","doc":"Get the TraceId of a Span.","ref":"OpenTelemetry.Span.html#trace_id/1"},{"type":"function","title":"OpenTelemetry.Span.tracestate/1","doc":"Get the Tracestate of a Span.","ref":"OpenTelemetry.Span.html#tracestate/1"},{"type":"function","title":"OpenTelemetry.Span.update_name/2","doc":"Updates the Span name.\n\nIt is highly discouraged to update the name of a Span after its creation. Span name is\noften used to group, filter and identify the logical groups of spans. And often, filtering\nlogic will be implemented before the Span creation for performance reasons. Thus the name\nupdate may interfere with this logic.\n\nThe function name is called UpdateName to differentiate this function from the regular\nproperty setter. It emphasizes that this operation signifies a major change for a Span\nand may lead to re-calculation of sampling or filtering decisions made previously\ndepending on the implementation.","ref":"OpenTelemetry.Span.html#update_name/2"},{"type":"type","title":"OpenTelemetry.Span.start_config/0","doc":"","ref":"OpenTelemetry.Span.html#t:start_config/0"},{"type":"type","title":"OpenTelemetry.Span.start_opts/0","doc":"","ref":"OpenTelemetry.Span.html#t:start_opts/0"},{"type":"module","title":"opentelemetry","doc":"The types defined here, and referencing records in opentelemetry.hrl are used to store trace information while being collected on the Erlang node. Thus, while the types are based on protos found in the opentelemetry-proto repo: src/opentelemetry/proto/trace/v1/trace.proto, they are not exact translations because further processing is done after the span has finished and can be vendor specific. For example, there is no count of the number of dropped attributes in the span record. And an attribute's value can be a function to only evaluate the value if it is actually used (at the time of exporting). And the stacktrace is a regular Erlang stack trace.","ref":"opentelemetry.html"},{"type":"function","title":"opentelemetry.convert_timestamp/2","doc":"Convert a native monotonic timestamp to POSIX time of any erlang:time_unit() . Meaning the time since Epoch. Epoch is defined to be 00:00:00 UTC, 1970-01-01.","ref":"opentelemetry.html#convert_timestamp/2"},{"type":"function","title":"opentelemetry.create_application_tracers/1","doc":null,"ref":"opentelemetry.html#create_application_tracers/1"},{"type":"function","title":"opentelemetry.event/2","doc":"Equivalent to event(opentelemetry:timestamp(), Name, Attributes) .","ref":"opentelemetry.html#event/2"},{"type":"function","title":"opentelemetry.event/3","doc":"Creates a Span event with the given Name and Attributes . The Span event is marked to have happened at Timestamp . The returned event can be used to add an event to a Span through otel_span:add_events/2 , for example.","ref":"opentelemetry.html#event/3"},{"type":"function","title":"opentelemetry.events/1","doc":"Creates a list of Span events from the given List . This is a convenience function to create a list of Span events from a list of {Time, Name, Attributes} or {Name, Attributes} tuples. It's equivalent to calling event/2 or event/3 multiple times. This function also automatically filters out any invalid tuple.","ref":"opentelemetry.html#events/1"},{"type":"function","title":"opentelemetry.get_application/1","doc":null,"ref":"opentelemetry.html#get_application/1"},{"type":"function","title":"opentelemetry.get_application_scope/1","doc":null,"ref":"opentelemetry.html#get_application_scope/1"},{"type":"function","title":"opentelemetry.get_application_tracer/1","doc":null,"ref":"opentelemetry.html#get_application_tracer/1"},{"type":"function","title":"opentelemetry.get_text_map_extractor/0","doc":null,"ref":"opentelemetry.html#get_text_map_extractor/0"},{"type":"function","title":"opentelemetry.get_text_map_injector/0","doc":null,"ref":"opentelemetry.html#get_text_map_injector/0"},{"type":"function","title":"opentelemetry.get_tracer/0","doc":"Returns the default global tracer. Without the opentelemetry application loaded (as a dependency) and started (or another SDK), this function returns the default value {otel_tracer_noop, []} .","ref":"opentelemetry.html#get_tracer/0"},{"type":"function","title":"opentelemetry.get_tracer/1","doc":"Returns the tracer for the given name. Passing {Name, Vsn, SchemaUrl} is the same as calling get_tracer(Name, Vsn, SchemaUrl) . See also: get_tracer/3 .","ref":"opentelemetry.html#get_tracer/1"},{"type":"function","title":"opentelemetry.get_tracer/3","doc":"Equivalent to get_tracer({Name, Vsn, SchemaUrl}) .","ref":"opentelemetry.html#get_tracer/3"},{"type":"function","title":"opentelemetry.instrumentation_library/3","doc":null,"ref":"opentelemetry.html#instrumentation_library/3"},{"type":"function","title":"opentelemetry.instrumentation_scope/3","doc":null,"ref":"opentelemetry.html#instrumentation_scope/3"},{"type":"function","title":"opentelemetry.link/1","doc":"Equivalent to link(SpanCtx, []) .","ref":"opentelemetry.html#link/1"},{"type":"function","title":"opentelemetry.link/2","doc":"Creates a Span link to the Span represented by the given SpanCtx . The returned link can be used in the links field of a Span.","ref":"opentelemetry.html#link/2"},{"type":"function","title":"opentelemetry.link/4","doc":"Creates a Span link to the Span represented by the given TraceId and SpanId . The returned link can be used in the links field of a Span.","ref":"opentelemetry.html#link/4"},{"type":"function","title":"opentelemetry.links/1","doc":"Creates a list of Span links from the given List . This is equivalent to calling link/2 or link/4 multiple times.","ref":"opentelemetry.html#links/1"},{"type":"function","title":"opentelemetry.set_default_tracer/1","doc":null,"ref":"opentelemetry.html#set_default_tracer/1"},{"type":"function","title":"opentelemetry.set_default_tracer/2","doc":null,"ref":"opentelemetry.html#set_default_tracer/2"},{"type":"function","title":"opentelemetry.set_text_map_extractor/1","doc":null,"ref":"opentelemetry.html#set_text_map_extractor/1"},{"type":"function","title":"opentelemetry.set_text_map_injector/1","doc":null,"ref":"opentelemetry.html#set_text_map_injector/1"},{"type":"function","title":"opentelemetry.set_text_map_propagator/1","doc":null,"ref":"opentelemetry.html#set_text_map_propagator/1"},{"type":"function","title":"opentelemetry.set_tracer/2","doc":null,"ref":"opentelemetry.html#set_tracer/2"},{"type":"function","title":"opentelemetry.start_tracer_provider/2","doc":null,"ref":"opentelemetry.html#start_tracer_provider/2"},{"type":"function","title":"opentelemetry.status/1","doc":"Create a Span status from the given Code . The returned status can be used to set the status of a Span through otel_span:set_status/2 , for example.","ref":"opentelemetry.html#status/1"},{"type":"function","title":"opentelemetry.status/2","doc":"Create a Span status from the given Code and with the given Message . The returned status can be used to set the status of a Span through otel_span:set_status/2 , for example.","ref":"opentelemetry.html#status/2"},{"type":"function","title":"opentelemetry.timestamp/0","doc":"A monotonically increasing time provided by the Erlang runtime system in the native time unit. This value is the most accurate and precise timestamp available from the Erlang runtime and should be used for finding durations or any timestamp that can be converted to a system time before being sent to another system.","ref":"opentelemetry.html#timestamp/0"},{"type":"function","title":"opentelemetry.timestamp_to_nano/1","doc":"Convert a native monotonic timestamp to nanosecond POSIX time. Meaning the time since Epoch. Epoch is defined to be 00:00:00 UTC, 1970-01-01.","ref":"opentelemetry.html#timestamp_to_nano/1"},{"type":"type","title":"opentelemetry.attribute/0","doc":null,"ref":"opentelemetry.html#t:attribute/0"},{"type":"type","title":"opentelemetry.attribute_key/0","doc":null,"ref":"opentelemetry.html#t:attribute_key/0"},{"type":"type","title":"opentelemetry.attribute_value/0","doc":null,"ref":"opentelemetry.html#t:attribute_value/0"},{"type":"type","title":"opentelemetry.attributes_map/0","doc":null,"ref":"opentelemetry.html#t:attributes_map/0"},{"type":"type","title":"opentelemetry.event/0","doc":null,"ref":"opentelemetry.html#t:event/0"},{"type":"type","title":"opentelemetry.event_name/0","doc":null,"ref":"opentelemetry.html#t:event_name/0"},{"type":"type","title":"opentelemetry.hex_span_id/0","doc":null,"ref":"opentelemetry.html#t:hex_span_id/0"},{"type":"type","title":"opentelemetry.hex_trace_id/0","doc":null,"ref":"opentelemetry.html#t:hex_trace_id/0"},{"type":"type","title":"opentelemetry.instrumentation_scope/0","doc":null,"ref":"opentelemetry.html#t:instrumentation_scope/0"},{"type":"type","title":"opentelemetry.link/0","doc":null,"ref":"opentelemetry.html#t:link/0"},{"type":"type","title":"opentelemetry.resource/0","doc":null,"ref":"opentelemetry.html#t:resource/0"},{"type":"type","title":"opentelemetry.span/0","doc":null,"ref":"opentelemetry.html#t:span/0"},{"type":"type","title":"opentelemetry.span_ctx/0","doc":null,"ref":"opentelemetry.html#t:span_ctx/0"},{"type":"type","title":"opentelemetry.span_id/0","doc":null,"ref":"opentelemetry.html#t:span_id/0"},{"type":"type","title":"opentelemetry.span_kind/0","doc":null,"ref":"opentelemetry.html#t:span_kind/0"},{"type":"type","title":"opentelemetry.span_name/0","doc":null,"ref":"opentelemetry.html#t:span_name/0"},{"type":"type","title":"opentelemetry.status/0","doc":null,"ref":"opentelemetry.html#t:status/0"},{"type":"type","title":"opentelemetry.status_code/0","doc":null,"ref":"opentelemetry.html#t:status_code/0"},{"type":"type","title":"opentelemetry.text_map/0","doc":null,"ref":"opentelemetry.html#t:text_map/0"},{"type":"type","title":"opentelemetry.timestamp/0","doc":null,"ref":"opentelemetry.html#t:timestamp/0"},{"type":"type","title":"opentelemetry.trace_flags/0","doc":null,"ref":"opentelemetry.html#t:trace_flags/0"},{"type":"type","title":"opentelemetry.trace_id/0","doc":null,"ref":"opentelemetry.html#t:trace_id/0"},{"type":"type","title":"opentelemetry.tracer/0","doc":null,"ref":"opentelemetry.html#t:tracer/0"},{"type":"type","title":"opentelemetry.tracestate/0","doc":null,"ref":"opentelemetry.html#t:tracestate/0"},{"type":"module","title":"otel_attributes","doc":"Functions to work with Attributes. An Attribute is a key-value pair with string or atom keys. See the specification .","ref":"otel_attributes.html"},{"type":"function","title":"otel_attributes.dropped/1","doc":"Returns the count of dropped attributes in the given Attributes .","ref":"otel_attributes.html#dropped/1"},{"type":"function","title":"otel_attributes.is_valid_attribute/2","doc":"Checks whether the given key-value pair makes for a valid attribute. For example: otel_attributes : is_valid_attribute ( &lt;&lt; &quot;key&quot; &gt;&gt; , &lt;&lt; &quot;value&quot; &gt;&gt; ) . %=&gt; true otel_attributes : is_valid_attribute ( atom_key , &lt;&lt; &quot;value&quot; &gt;&gt; ) . %=&gt; true otel_attributes : is_valid_attribute ( 123 , &lt;&lt; &quot;value&quot; &gt;&gt; ) . %=&gt; false","ref":"otel_attributes.html#is_valid_attribute/2"},{"type":"function","title":"otel_attributes.map/1","doc":"Returns the Attributes in the form of a map. For example: otel_attributes : new ( [ ] , 10 , 10 ) , otel_attributes : set ( &lt;&lt; &quot;key&quot; &gt;&gt; , &lt;&lt; &quot;value&quot; &gt;&gt; , Attributes ) , otel_attributes : map ( Attributes ) . %=&gt; #{&lt;&lt;&quot;key&quot;&gt;&gt; =&gt; &lt;&lt;&quot;value&quot;&gt;&gt;}","ref":"otel_attributes.html#map/1"},{"type":"function","title":"otel_attributes.new/3","doc":"Creates a new Attributes from Pairs with the given count and value length limits. Pairs can be a list of key-value pairs or a map. If Pairs is not a list or map, the function returns an empty Attributes .","ref":"otel_attributes.html#new/3"},{"type":"function","title":"otel_attributes.set/2","doc":"Sets the given key-value pairs in the given Attributes . Overrides the existing value for a given key if it already exists in Attributes . NewListOrMap can be a list of key-value pairs or a map. If NewListOrMap is not a list or map, the function returns Attributes as is. Returns the updated Attributes .","ref":"otel_attributes.html#set/2"},{"type":"function","title":"otel_attributes.set/3","doc":"Sets the given key-value pair in the given Attributes . Overrides the existing value under Key if Key already exists. Returns the updated Attributes .","ref":"otel_attributes.html#set/3"},{"type":"type","title":"otel_attributes.t/0","doc":null,"ref":"otel_attributes.html#t:t/0"},{"type":"module","title":"otel_baggage","doc":"Baggage is used to annotate telemetry, adding context and information to metrics, traces, and logs. It is represented by a set of name/value pairs describing user-defined properties. The baggage can be stored either in the current context (with set/1 or set/3 , for example) or in an explicit Context (see otel_ctx ).","ref":"otel_baggage.html"},{"type":"function","title":"otel_baggage.clear/0","doc":"Clears the baggage, removing all the current key-value pairs.","ref":"otel_baggage.html#clear/0"},{"type":"function","title":"otel_baggage.clear/1","doc":"Clears the baggage for the given context, removing all the current key-value pairs.","ref":"otel_baggage.html#clear/1"},{"type":"function","title":"otel_baggage.get_all/0","doc":"Returns the baggage from the process dictionary.","ref":"otel_baggage.html#get_all/0"},{"type":"function","title":"otel_baggage.get_all/1","doc":"Returns the baggage for the given context.","ref":"otel_baggage.html#get_all/1"},{"type":"function","title":"otel_baggage.set/1","doc":"Sets the given key-value pairs in the current baggage. If you need to set metadata for the key-value pair, use set/3 instead.","ref":"otel_baggage.html#set/1"},{"type":"function","title":"otel_baggage.set/2","doc":"Sets the given key-value pair in the current baggage, or sets the given key-value pairs in the baggage for the given context. Returns ok when using the set(Key, Value) form, or the updated context when using the set(Ctx, KeyValues) form.","ref":"otel_baggage.html#set/2"},{"type":"function","title":"otel_baggage.set/3","doc":"Sets the given key-value pair in the current baggage (with the associated metadata), or sets the given key-value pair in the baggage for the given context. Returns ok when using the set(Key, Value, Metadata) form, or the updated context when using the set(Ctx, Key, Value) form.","ref":"otel_baggage.html#set/3"},{"type":"function","title":"otel_baggage.set/4","doc":"Sets the given key-value pair in the baggage for the given context, with the associated metadata. Returns the updated context.","ref":"otel_baggage.html#set/4"},{"type":"function","title":"otel_baggage.set_to/2","doc":"Sets the given key-value pairs in the baggage for the given context. Returns the updated context.","ref":"otel_baggage.html#set_to/2"},{"type":"function","title":"otel_baggage.set_to/3","doc":"Sets the given key-value pair in the baggage for the given context. Returns the updated context.","ref":"otel_baggage.html#set_to/3"},{"type":"function","title":"otel_baggage.set_to/4","doc":"Sets the given key-value pair in the baggage for the given context, with the associated metadata. Returns the updated context.","ref":"otel_baggage.html#set_to/4"},{"type":"type","title":"otel_baggage.input_key/0","doc":"An input key, that is, a key that is then converted to a UTF-8 binary.","ref":"otel_baggage.html#t:input_key/0"},{"type":"type","title":"otel_baggage.input_value/0","doc":"An input value, that is, a value that is then converted to a UTF-8 binary.","ref":"otel_baggage.html#t:input_value/0"},{"type":"type","title":"otel_baggage.key/0","doc":"The type for the baggage key, which is a UTF-8 binary.","ref":"otel_baggage.html#t:key/0"},{"type":"type","title":"otel_baggage.metadata/0","doc":"The type for the baggage metadata, which is a list of UTF-8 binaries or a list of tuples of UTF-8 binaries (as key-value pairs).","ref":"otel_baggage.html#t:metadata/0"},{"type":"type","title":"otel_baggage.t/0","doc":"The type for the baggage.","ref":"otel_baggage.html#t:t/0"},{"type":"type","title":"otel_baggage.value/0","doc":"The type for the baggage value, which is a UTF-8 binary.","ref":"otel_baggage.html#t:value/0"},{"type":"module","title":"otel_ctx","doc":"Ctx is responsible for propagating values within a process that are associated with a particular Trace or set of Baggage. OpenTelemetry.Tracer and OpenTelemetry.Baggage handle updating the Context. Functions in this module include variants that explicitly take a Ctx argument and variants that implicitly use the current context , which is the context stored in the process dictionary.","ref":"otel_ctx.html"},{"type":"function","title":"otel_ctx.attach/1","doc":"Attaches the given context to the current process. Essentially, this sets Ctx as the current context .","ref":"otel_ctx.html#attach/1"},{"type":"function","title":"otel_ctx.clear/0","doc":"Removes all key-value pairs from the current context.","ref":"otel_ctx.html#clear/0"},{"type":"function","title":"otel_ctx.clear/1","doc":"Removes all key-value pairs from the given context. Returns an empty context.","ref":"otel_ctx.html#clear/1"},{"type":"function","title":"otel_ctx.detach/1","doc":"Detaches the given context from the current process.","ref":"otel_ctx.html#detach/1"},{"type":"function","title":"otel_ctx.get_current/0","doc":"Returns the current context.","ref":"otel_ctx.html#get_current/0"},{"type":"function","title":"otel_ctx.get_value/1","doc":"Gets a value from the current context under the given key.","ref":"otel_ctx.html#get_value/1"},{"type":"function","title":"otel_ctx.get_value/2","doc":"Gets a value from the current context under the given key, or returns the default value if the key is not present in the current context.","ref":"otel_ctx.html#get_value/2"},{"type":"function","title":"otel_ctx.get_value/3","doc":"Gets a value from the given context under the given key, or returns the default value if the key is not present in the given context or if Ctx is undefined .","ref":"otel_ctx.html#get_value/3"},{"type":"function","title":"otel_ctx.new/0","doc":"Creates a new context.","ref":"otel_ctx.html#new/0"},{"type":"function","title":"otel_ctx.remove/1","doc":"Removes the value under the given key from the current context.","ref":"otel_ctx.html#remove/1"},{"type":"function","title":"otel_ctx.remove/2","doc":"Removes the value under the given key from the given context. Returns the updated context.","ref":"otel_ctx.html#remove/2"},{"type":"function","title":"otel_ctx.set_value/2","doc":"Sets a value in the current context under the given key.","ref":"otel_ctx.html#set_value/2"},{"type":"function","title":"otel_ctx.set_value/3","doc":"Sets a value in the given context under the given key. Returns the updated context.","ref":"otel_ctx.html#set_value/3"},{"type":"function","title":"otel_ctx.with_ctx/2","doc":"Attaches a context and runs a function, detaching the context at the end. Returns the detached context.","ref":"otel_ctx.html#with_ctx/2"},{"type":"type","title":"otel_ctx.key/0","doc":"A context key.","ref":"otel_ctx.html#t:key/0"},{"type":"type","title":"otel_ctx.t/0","doc":"A context map.","ref":"otel_ctx.html#t:t/0"},{"type":"opaque","title":"otel_ctx.token/0","doc":"An opaque token that represents a context.","ref":"otel_ctx.html#t:token/0"},{"type":"type","title":"otel_ctx.value/0","doc":"A context value.","ref":"otel_ctx.html#t:value/0"},{"type":"module","title":"otel_span","doc":"Span behaviour.","ref":"otel_span.html"},{"type":"function","title":"otel_span.add_event/3","doc":"Adds an event to the given span context. Returns false if the given span context is not recording, or if the event Name is not valid.","ref":"otel_span.html#add_event/3"},{"type":"function","title":"otel_span.add_events/2","doc":"Same as add_event/3 , but takes a list of events. Returns false if the given span context is not recording.","ref":"otel_span.html#add_events/2"},{"type":"function","title":"otel_span.end_span/1","doc":"Ends the given span context. If SpanCtx is not recording, this function doesn't do anything. Returns the updated span context.","ref":"otel_span.html#end_span/1"},{"type":"function","title":"otel_span.end_span/2","doc":"Ends the given span context with the given timestamp. If SpanCtx is not recording, this function doesn't do anything. If Timestamp is undefined , this is equivalent to end_span/1 . Returns the updated span context.","ref":"otel_span.html#end_span/2"},{"type":"function","title":"otel_span.hex_span_ctx/1","doc":null,"ref":"otel_span.html#hex_span_ctx/1"},{"type":"function","title":"otel_span.hex_span_id/1","doc":null,"ref":"otel_span.html#hex_span_id/1"},{"type":"function","title":"otel_span.hex_trace_id/1","doc":null,"ref":"otel_span.html#hex_trace_id/1"},{"type":"function","title":"otel_span.is_recording/1","doc":"Returns whether the span is recording.","ref":"otel_span.html#is_recording/1"},{"type":"function","title":"otel_span.is_valid/1","doc":"Returns whether the span context is valid.","ref":"otel_span.html#is_valid/1"},{"type":"function","title":"otel_span.record_exception/5","doc":null,"ref":"otel_span.html#record_exception/5"},{"type":"function","title":"otel_span.record_exception/6","doc":null,"ref":"otel_span.html#record_exception/6"},{"type":"function","title":"otel_span.set_attribute/3","doc":null,"ref":"otel_span.html#set_attribute/3"},{"type":"function","title":"otel_span.set_attributes/2","doc":null,"ref":"otel_span.html#set_attributes/2"},{"type":"function","title":"otel_span.set_status/2","doc":null,"ref":"otel_span.html#set_status/2"},{"type":"function","title":"otel_span.set_status/3","doc":null,"ref":"otel_span.html#set_status/3"},{"type":"function","title":"otel_span.span_id/1","doc":"Returns the span ID of the given span context.","ref":"otel_span.html#span_id/1"},{"type":"function","title":"otel_span.trace_id/1","doc":"Returns the trace ID of the given span context.","ref":"otel_span.html#trace_id/1"},{"type":"function","title":"otel_span.tracestate/1","doc":null,"ref":"otel_span.html#tracestate/1"},{"type":"function","title":"otel_span.update_name/2","doc":"Updates the name of the given span context to Name . Returns false if the given span context is not recording, or if the name Name is not valid.","ref":"otel_span.html#update_name/2"},{"type":"function","title":"otel_span.validate_start_opts/1","doc":"Validates the start options for a span and fills in defaults.","ref":"otel_span.html#validate_start_opts/1"},{"type":"type","title":"otel_span.start_config/0","doc":"Start options for a span.","ref":"otel_span.html#t:start_config/0"},{"type":"type","title":"otel_span.start_opts/0","doc":null,"ref":"otel_span.html#t:start_opts/0"},{"type":"module","title":"OpenTelemetry.Tracer","doc":"This module contains macros for Tracer operations around the lifecycle of the Spans within a Trace.\n\nThe Tracer is able to start a new Span as a child of the active Span of the current process, set\na different Span to be the current Span by passing the Span's context, end a Span or run a code\nblock within the context of a newly started span that is ended when the code block completes.\n\nThe macros `start_span` and `with_span` use the Tracer associated with the Application the module\nis included in. These Tracers are created at boot time for each loaded Application.\n\n    require OpenTelemetry.Tracer, as: Tracer\n\n    Tracer.with_span \"span-1\" do\n      ... do something ...\n    end","ref":"OpenTelemetry.Tracer.html"},{"type":"function","title":"OpenTelemetry.Tracer.add_event/2","doc":"Add an event to the currently active Span.","ref":"OpenTelemetry.Tracer.html#add_event/2"},{"type":"function","title":"OpenTelemetry.Tracer.add_events/1","doc":"Add a list of events to the currently active Span.","ref":"OpenTelemetry.Tracer.html#add_events/1"},{"type":"function","title":"OpenTelemetry.Tracer.current_span_ctx/0","doc":"Returns the currently active `t:OpenTelemetry.span_ctx/0`.","ref":"OpenTelemetry.Tracer.html#current_span_ctx/0"},{"type":"function","title":"OpenTelemetry.Tracer.current_span_ctx/1","doc":"Returns the `t:OpenTelemetry.span_ctx/0` active in Context `ctx`.","ref":"OpenTelemetry.Tracer.html#current_span_ctx/1"},{"type":"function","title":"OpenTelemetry.Tracer.end_span/1","doc":"End the currently active Span and sets its end timestamp.\nThis has no effect on any child Spans that may exist of this Span.\n\nTo end a specific span, see `OpenTelemetry.Span.end_span/1`.\n\nThe Span in the current Context has its `is_recording` set to `false`.","ref":"OpenTelemetry.Tracer.html#end_span/1"},{"type":"function","title":"OpenTelemetry.Tracer.record_exception/3","doc":"Record an exception as an event, following the semantics convetions for exceptions.\n\nIf trace is not provided, the stacktrace is retrieved from `Process.info/2`","ref":"OpenTelemetry.Tracer.html#record_exception/3"},{"type":"function","title":"OpenTelemetry.Tracer.set_attribute/2","doc":"Set an attribute with key and value on the currently active Span.","ref":"OpenTelemetry.Tracer.html#set_attribute/2"},{"type":"function","title":"OpenTelemetry.Tracer.set_attributes/1","doc":"Add a list of attributes to the currently active Span.","ref":"OpenTelemetry.Tracer.html#set_attributes/1"},{"type":"function","title":"OpenTelemetry.Tracer.set_current_span/1","doc":"Takes a `t:OpenTelemetry.span_ctx/0` and the Tracer sets it to the currently active Span.","ref":"OpenTelemetry.Tracer.html#set_current_span/1"},{"type":"function","title":"OpenTelemetry.Tracer.set_current_span/2","doc":"Takes a `t:OpenTelemetry.Ctx.t/0` and the `t:OpenTelemetry.span_ctx/0` and the Tracer sets\nit to the current span in the pass Context.","ref":"OpenTelemetry.Tracer.html#set_current_span/2"},{"type":"function","title":"OpenTelemetry.Tracer.set_status/1","doc":"Sets the Status of the currently active Span.\n\nIf used, this will override the default Span Status, which is `:unset`.","ref":"OpenTelemetry.Tracer.html#set_status/1"},{"type":"function","title":"OpenTelemetry.Tracer.set_status/2","doc":"Creates and sets the Status of the currently active Span.\n\nIf used, this will override the default Span Status, which is `:unset`.","ref":"OpenTelemetry.Tracer.html#set_status/2"},{"type":"macro","title":"OpenTelemetry.Tracer.start_span/2","doc":"Starts a new span and does not make it the current active span of the current process.\n\nThe current active Span is used as the parent of the created Span.","ref":"OpenTelemetry.Tracer.html#start_span/2"},{"type":"macro","title":"OpenTelemetry.Tracer.start_span/3","doc":"Starts a new span and does not make it the current active span of the current process.\n\nThe current active Span is used as the parent of the created Span.","ref":"OpenTelemetry.Tracer.html#start_span/3"},{"type":"function","title":"OpenTelemetry.Tracer.update_name/1","doc":"Updates the Span name.\n\nIt is highly discouraged to update the name of a Span after its creation. Span name is\noften used to group, filter and identify the logical groups of spans. And often, filtering\nlogic will be implemented before the Span creation for performance reasons. Thus the name\nupdate may interfere with this logic.\n\nThe function name is called UpdateName to differentiate this function from the regular\nproperty setter. It emphasizes that this operation signifies a major change for a Span\nand may lead to re-calculation of sampling or filtering decisions made previously\ndepending on the implementation.","ref":"OpenTelemetry.Tracer.html#update_name/1"},{"type":"macro","title":"OpenTelemetry.Tracer.with_span/3","doc":"Creates a new span which is set to the currently active Span in the Context of the block.\nThe Span is ended automatically when the `block` completes and the Context is what it was\nbefore the block.\n\nSee `start_span/2` and `end_span/0`.","ref":"OpenTelemetry.Tracer.html#with_span/3"},{"type":"macro","title":"OpenTelemetry.Tracer.with_span/4","doc":"Creates a new span which is set to the currently active Span in the Context of the block.\nThe Span is ended automatically when the `block` completes and the Context is what it was\nbefore the block.\n\nSee `start_span/2` and `end_span/0`.","ref":"OpenTelemetry.Tracer.html#with_span/4"},{"type":"behaviour","title":"otel_tracer","doc":null,"ref":"otel_tracer.html"},{"type":"function","title":"otel_tracer.current_span_ctx/0","doc":null,"ref":"otel_tracer.html#current_span_ctx/0"},{"type":"function","title":"otel_tracer.current_span_ctx/1","doc":null,"ref":"otel_tracer.html#current_span_ctx/1"},{"type":"function","title":"otel_tracer.from_remote_span/3","doc":"Returns a span_ctx record with is_recording set to false and is_remote set to true . This is mainly for use in propagators when they extract a Span to be used as a parent.","ref":"otel_tracer.html#from_remote_span/3"},{"type":"function","title":"otel_tracer.non_recording_span/3","doc":"Returns a span_ctx record with is_recording set to false . This is mainly for use in propagators when they extract a Span to be used as a parent.","ref":"otel_tracer.html#non_recording_span/3"},{"type":"function","title":"otel_tracer.set_current_span/1","doc":null,"ref":"otel_tracer.html#set_current_span/1"},{"type":"function","title":"otel_tracer.set_current_span/2","doc":null,"ref":"otel_tracer.html#set_current_span/2"},{"type":"function","title":"otel_tracer.start_span/3","doc":null,"ref":"otel_tracer.html#start_span/3"},{"type":"function","title":"otel_tracer.start_span/4","doc":null,"ref":"otel_tracer.html#start_span/4"},{"type":"callback","title":"otel_tracer.start_span/4","doc":null,"ref":"otel_tracer.html#c:start_span/4"},{"type":"function","title":"otel_tracer.update_logger_process_metadata/1","doc":null,"ref":"otel_tracer.html#update_logger_process_metadata/1"},{"type":"function","title":"otel_tracer.with_span/4","doc":null,"ref":"otel_tracer.html#with_span/4"},{"type":"function","title":"otel_tracer.with_span/5","doc":null,"ref":"otel_tracer.html#with_span/5"},{"type":"callback","title":"otel_tracer.with_span/5","doc":null,"ref":"otel_tracer.html#c:with_span/5"},{"type":"type","title":"otel_tracer.traced_fun/1","doc":null,"ref":"otel_tracer.html#t:traced_fun/1"},{"type":"module","title":"otel_tracer_noop","doc":null,"ref":"otel_tracer_noop.html"},{"type":"function","title":"otel_tracer_noop.end_span/2","doc":null,"ref":"otel_tracer_noop.html#end_span/2"},{"type":"function","title":"otel_tracer_noop.noop_span_ctx/0","doc":null,"ref":"otel_tracer_noop.html#noop_span_ctx/0"},{"type":"function","title":"otel_tracer_noop.start_span/4","doc":null,"ref":"otel_tracer_noop.html#start_span/4"},{"type":"function","title":"otel_tracer_noop.with_span/5","doc":null,"ref":"otel_tracer_noop.html#with_span/5"},{"type":"module","title":"otel_tracer_provider","doc":"This module defines the API for a TracerProvider. A TracerProvider stores Tracer configuration and is how Tracers are accessed. An implementation must be a gen_server that handles the API's calls. The SDK should register a TracerProvider with the name otel_tracer_provider which is used as the default global Provider.","ref":"otel_tracer_provider.html"},{"type":"function","title":"otel_tracer_provider.force_flush/0","doc":null,"ref":"otel_tracer_provider.html#force_flush/0"},{"type":"function","title":"otel_tracer_provider.force_flush/1","doc":null,"ref":"otel_tracer_provider.html#force_flush/1"},{"type":"function","title":"otel_tracer_provider.get_tracer/3","doc":null,"ref":"otel_tracer_provider.html#get_tracer/3"},{"type":"function","title":"otel_tracer_provider.get_tracer/4","doc":null,"ref":"otel_tracer_provider.html#get_tracer/4"},{"type":"function","title":"otel_tracer_provider.resource/0","doc":null,"ref":"otel_tracer_provider.html#resource/0"},{"type":"function","title":"otel_tracer_provider.resource/1","doc":null,"ref":"otel_tracer_provider.html#resource/1"},{"type":"function","title":"otel_tracer_provider.start/2","doc":null,"ref":"otel_tracer_provider.html#start/2"},{"type":"module","title":"otel_tracestate","doc":"tracestate provides additional vendor-specific trace identification information across different distributed tracing systems. It represents an immutable list consisting of key/value pairs, each pair is referred to as a list-member. Keys and values are strings of up to 256 printable US-ASCII characters, conforming to the W3C spec https://www.w3.org/TR/trace-context/#tracestate-field","ref":"otel_tracestate.html"},{"type":"function","title":"otel_tracestate.add/3","doc":null,"ref":"otel_tracestate.html#add/3"},{"type":"function","title":"otel_tracestate.decode_header/1","doc":null,"ref":"otel_tracestate.html#decode_header/1"},{"type":"function","title":"otel_tracestate.encode_header/1","doc":null,"ref":"otel_tracestate.html#encode_header/1"},{"type":"function","title":"otel_tracestate.get/2","doc":null,"ref":"otel_tracestate.html#get/2"},{"type":"function","title":"otel_tracestate.new/0","doc":null,"ref":"otel_tracestate.html#new/0"},{"type":"function","title":"otel_tracestate.new/1","doc":null,"ref":"otel_tracestate.html#new/1"},{"type":"function","title":"otel_tracestate.remove/2","doc":null,"ref":"otel_tracestate.html#remove/2"},{"type":"function","title":"otel_tracestate.update/3","doc":null,"ref":"otel_tracestate.html#update/3"},{"type":"type","title":"otel_tracestate.members/0","doc":null,"ref":"otel_tracestate.html#t:members/0"},{"type":"type","title":"otel_tracestate.t/0","doc":null,"ref":"otel_tracestate.html#t:t/0"},{"type":"behaviour","title":"otel_propagator","doc":"A Propagator injects or extracts data from a Context so information like baggage and trace context can be transported along with cross service requests, like an HTTP request. Propagators are defined based on the type of encoding they inject and extract. At this time there is only a TextMapPropagator, otel_propagator_text_map , which works on ASCII keys and values. This behaviour is only for defining the callbacks used by each propagator per type and is only used by developers adding a new type of propagator (like for binary protocols), not implementations of propagators themselves (like B3 or W3C TraceContext). Users configure and call propagators based on their type. See the docs for otel_propagator_text_map for more details.","ref":"otel_propagator.html"},{"type":"callback","title":"otel_propagator.extract/2","doc":"Extracts a value from a carrier.","ref":"otel_propagator.html#c:extract/2"},{"type":"callback","title":"otel_propagator.extract_to/3","doc":"Extracts a value from a carrier into a context.","ref":"otel_propagator.html#c:extract_to/3"},{"type":"callback","title":"otel_propagator.inject/2","doc":"Sets a value into a carrier.","ref":"otel_propagator.html#c:inject/2"},{"type":"callback","title":"otel_propagator.inject_from/3","doc":"Sets a value from a context into a carrier.","ref":"otel_propagator.html#c:inject_from/3"},{"type":"type","title":"otel_propagator.builtin/0","doc":"A built-in propagator.","ref":"otel_propagator.html#t:builtin/0"},{"type":"type","title":"otel_propagator.carrier/0","doc":"A carrier, which can be any type.","ref":"otel_propagator.html#t:carrier/0"},{"type":"type","title":"otel_propagator.t/0","doc":"A propagator, which can be a built-in propagator, a module, or a module and associated term.","ref":"otel_propagator.html#t:t/0"},{"type":"module","title":"otel_propagator_b3","doc":"An implementation of otel_propagator_text_map that injects and extracts trace context using the B3 specification from Zipkin. Since trace_context and baggage are the two default propagators, the global TextMap Propagators must be configured if B3 is to be used for propagation: { text_map_propagators , [ b3 , baggage ] } , To use B3 multi-header format use: { text_map_propagators , [ b3multi , baggage ] } , CompositePropagator = otel_propagator_text_map_composite : create ( [ b3 , baggage ] ) , opentelemetry : set_text_map_propagator ( CompositePropagator ) . It is also possible to set a separate list of injectors or extractors. For example, if the service should extract B3 encoded context but you only want to inject context encoded with the W3C TraceContext format (maybe you have some services only supporting B3 that are making requests to your server but you have no reason to continue propagating in both formats when communicating to other services further down the stack). In that case you would instead set configuration like: { text_map_extractors , [ b3 , trace_context , baggage ] } , { text_map_injectors , [ trace_context , baggage ] } , Or using calls to opentelemetry at runtime: B3CompositePropagator = otel_propagator_text_map_composite : create ( [ b3 , trace_context , baggage ] ) , CompositePropagator = otel_propagator_text_map_composite : create ( [ trace_context , baggage ] ) , opentelemetry : set_text_map_extractor ( B3CompositePropagator ) , opentelemetry : set_text_map_injector ( CompositePropagator ) .","ref":"otel_propagator_b3.html"},{"type":"module","title":"otel_propagator_b3multi","doc":"An implementation of otel_propagator_text_map that injects and extracts trace context using the B3 multi header format specification from Zipkin. See also: otel_propagator_b3 .","ref":"otel_propagator_b3multi.html"},{"type":"module","title":"otel_propagator_b3single","doc":"An implementation of otel_propagator_text_map that injects and extracts trace context using the B3 single header format specification from Zipkin. See also: otel_propagator_b3 .","ref":"otel_propagator_b3single.html"},{"type":"module","title":"otel_propagator_baggage","doc":"An implementation of otel_propagator_text_map that injects and extracts baggage using the W3C Baggage format . This propagator along with otel_propagator_trace_context are used by default. The global TextMap Propagators can be configured in the application environment: { text_map_propagators , [ trace_context , baggage ] } , Or by calling opentelemetry:set_text_map_propagator/1 .","ref":"otel_propagator_baggage.html"},{"type":"behaviour","title":"otel_propagator_text_map","doc":"A TextMap Propagator is a Propagator that performs injection and extraction with ASCII keys and values. An example of configuring the TextMap Propagator to inject and extract Baggage and TraceContext: { text_map_propagators , [ trace_context , baggage ] } , The propagators are then used at the points that cross-service communication is performed. By default, inject/3 and extract/3 work on a generic list of 2-tuple's with binary string keys and values. You can pass (as an argument) a user-defined function for setting a key/value in the carrier and for getting the value of a key. For example, injecting and extracting to and from Hackney headers could be done with Hackney-specific functions: set_header ( Key , Value , Headers ) -&gt; hackney_headers : store ( Key , Value , Headers ) . some_fun_calling_hackney ( ) -&gt; Headers = otel_propagator_text_map : inject ( opentelemetry : get_text_map_injector ( ) , hackney_headers : new ( ) , fun set_header / 2 ) , %% ... An example of extraction in an Elli request handler: get_header ( Req , Key ) -&gt; elli_request : get_header ( Key , Req , Default ) . handle ( Req , _ Args ) -&gt; otel_propagator_text_map : extract ( Req , fun get_header / 2 ) , %% ... { ok , [ ] , &lt;&lt; &quot;hello world&quot; &gt;&gt; } .","ref":"otel_propagator_text_map.html"},{"type":"function","title":"otel_propagator_text_map.extract/1","doc":"Extracts the current context from the provided Carrier using the current TextMap Propagator.","ref":"otel_propagator_text_map.html#extract/1"},{"type":"function","title":"otel_propagator_text_map.extract/2","doc":"Extracts the current context from the provided Carrier using the given Propagator .","ref":"otel_propagator_text_map.html#extract/2"},{"type":"function","title":"otel_propagator_text_map.extract/4","doc":"Extracts the current context from the provided Carrier using the given Propagator and functions to get all the keys and get the keys from the carrier.","ref":"otel_propagator_text_map.html#extract/4"},{"type":"callback","title":"otel_propagator_text_map.extract/5","doc":null,"ref":"otel_propagator_text_map.html#c:extract/5"},{"type":"function","title":"otel_propagator_text_map.extract_to/2","doc":"Equivalent to extract_to(Context, opentelemetry:get_text_map_extractor(), Carrier) .","ref":"otel_propagator_text_map.html#extract_to/2"},{"type":"function","title":"otel_propagator_text_map.extract_to/3","doc":"Equivalent to extract_to(Context, Propagator, Carrier, fun default_carrier_keys/1, fun default_carrier_get/2) .","ref":"otel_propagator_text_map.html#extract_to/3"},{"type":"function","title":"otel_propagator_text_map.extract_to/5","doc":"Extracts the current context from the provided Carrier using the given Propagator and functions to get all the keys and get the keys from the carrier.","ref":"otel_propagator_text_map.html#extract_to/5"},{"type":"callback","title":"otel_propagator_text_map.fields/1","doc":null,"ref":"otel_propagator_text_map.html#c:fields/1"},{"type":"function","title":"otel_propagator_text_map.inject/1","doc":"Injects Carrier into the current context using the current TextMap Propagator. See also: inject/2 .","ref":"otel_propagator_text_map.html#inject/1"},{"type":"function","title":"otel_propagator_text_map.inject/2","doc":"Injects Carrier into the current context using the provided Propagator . By default, the Carrier is set using the a default carrier set function. See also: inject/3 .","ref":"otel_propagator_text_map.html#inject/2"},{"type":"function","title":"otel_propagator_text_map.inject/3","doc":"Injects Carrier (through CarrierSetFun ) into the current context using the provided Propagator .","ref":"otel_propagator_text_map.html#inject/3"},{"type":"callback","title":"otel_propagator_text_map.inject/4","doc":null,"ref":"otel_propagator_text_map.html#c:inject/4"},{"type":"function","title":"otel_propagator_text_map.inject_from/2","doc":"Equivalent to inject_from(Context, opentelemetry:get_text_map_injector(), Carrier) .","ref":"otel_propagator_text_map.html#inject_from/2"},{"type":"function","title":"otel_propagator_text_map.inject_from/3","doc":"Equivalent to inject_from(Context, Propagator, Carrier, fun default_carrier_set/3) .","ref":"otel_propagator_text_map.html#inject_from/3"},{"type":"function","title":"otel_propagator_text_map.inject_from/4","doc":"Injects Carrier (through CarrierSetFun ) into the given Context using the provided propagator Propagator .","ref":"otel_propagator_text_map.html#inject_from/4"},{"type":"type","title":"otel_propagator_text_map.carrier_get/0","doc":null,"ref":"otel_propagator_text_map.html#t:carrier_get/0"},{"type":"type","title":"otel_propagator_text_map.carrier_keys/0","doc":null,"ref":"otel_propagator_text_map.html#t:carrier_keys/0"},{"type":"type","title":"otel_propagator_text_map.carrier_set/0","doc":null,"ref":"otel_propagator_text_map.html#t:carrier_set/0"},{"type":"type","title":"otel_propagator_text_map.default_text_map_carrier/0","doc":null,"ref":"otel_propagator_text_map.html#t:default_text_map_carrier/0"},{"type":"type","title":"otel_propagator_text_map.field_key/0","doc":null,"ref":"otel_propagator_text_map.html#t:field_key/0"},{"type":"type","title":"otel_propagator_text_map.field_value/0","doc":null,"ref":"otel_propagator_text_map.html#t:field_value/0"},{"type":"type","title":"otel_propagator_text_map.propagator_options/0","doc":null,"ref":"otel_propagator_text_map.html#t:propagator_options/0"},{"type":"type","title":"otel_propagator_text_map.t/0","doc":null,"ref":"otel_propagator_text_map.html#t:t/0"},{"type":"module","title":"otel_propagator_text_map_composite","doc":"A Composite TextMap Propagator is a Propagator that performs run multiple TextMap Propagators in a specified order. An example of creating a Composite TextMap Propagator to inject and extract Baggage and TraceContext: Propagator = otel_propagator_text_map_composite : create ( [ trace_context , baggage ] ) , otel_propagator_text_map : extract ( Propagator , Carrier )","ref":"otel_propagator_text_map_composite.html"},{"type":"function","title":"otel_propagator_text_map_composite.create/1","doc":"Create a new Composite TextMap Propagator. The Propagators list is a list of atoms that represent the suffix of the module name of the TextMap Propagator to be used.","ref":"otel_propagator_text_map_composite.html#create/1"},{"type":"module","title":"otel_propagator_text_map_noop","doc":"This no-op TextMap Propagator makes no changes to the context or the carrier when doing an extract or inject call.","ref":"otel_propagator_text_map_noop.html"},{"type":"module","title":"otel_propagator_trace_context","doc":"An implementation of otel_propagator_text_map that injects and extracts trace context using the W3C TraceContext format . This propagator along with otel_propagator_baggage are used by default. The global TextMap Propagators can be configured in the application environment: { text_map_propagators , [ trace_context , baggage ] } , Or by calling opentelemetry:set_text_map_propagator/1 .","ref":"otel_propagator_trace_context.html"},{"type":"extras","title":"Erlang/Elixir OpenTelemetry API","doc":"# Erlang/Elixir OpenTelemetry API\n\n[![EEF Observability WG project](https://img.shields.io/badge/EEF-Observability-black)](https://github.com/erlef/eef-observability-wg)\n[![Hex.pm](https://img.shields.io/hexpm/v/opentelemetry)](https://hex.pm/packages/opentelemetry_api)\n\nThis is the API portion of [OpenTelemetry](https://opentelemetry.io/) for Erlang\nand Elixir Applications, implementing the API portion of [the specification](https://github.com/open-telemetry/opentelemetry-specification).\n\nThis is a library, it does not start any processes, and should be the only\nOpenTelemetry dependency of Erlang/Elixir Applications.","ref":"readme.html"},{"type":"extras","title":"Use - Erlang/Elixir OpenTelemetry API","doc":"There are both Erlang and Elixir macros that make use of the current module's\nname to lookup a [Named\nTracer](https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/glossary.md#tracer-name--meter-name)\n-- a Named Tracer is created for each Application loaded in the system at start\ntime -- for you and can be used for Trace and Span operations:\n\n``` erlang\n-include_lib(\"opentelemetry_api/include/otel_tracer.hrl\").\n\nsome_fun() ->\n    ?with_span(<<\"some_fun/0\">>, #{}, \n        fun(_SpanCtx) -> \n            ...\n            ?set_attribute(<<\"key\">>, <<\"value\">>),\n            ...\n        end),\n```\n\n``` elixir\nrequire OpenTelemetry.Tracer\n      \ndef some_fun() do\n    OpenTelemetry.Tracer.with_span \"some-span\" do\n      ...\n      OpenTelemetry.Tracer.set_attribute(\"key\", \"value\")\n      ...\n    end\nend\n```\n\n#","ref":"readme.html#use"},{"type":"extras","title":"Tracing API - Erlang/Elixir OpenTelemetry API","doc":"The macros and functions available for Elixir in `OpenTelemetry.Tracer` and the\nErlang macros in `otel_tracer.hrl` are the best way to work with Spans. They\nwill automatically use the Tracer named for the Application the module using the\nmacro is in. For example, the Spans created in\n[opentelemetry_oban](https://hex.pm/packages/opentelemetry_oban) use the\n`with_span` macro resulting in the Span being created with the\n`opentelemetry_oban` named Tracer and associated with the [Instrumentation\nLibrary](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/glossary.md#instrumentation-library)\nof the same name and version of the Tracer -- the version also matches the\n`opentelemetry_oban` Application version.\n\n##","ref":"readme.html#tracing-api"},{"type":"extras","title":"Context - Erlang/Elixir OpenTelemetry API","doc":"[Context](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/context/context.md) is used to pass values associated with the current [execution\nunit](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/glossary.md#execution-unit).\nAt this time the only values kept in the Context by this OpenTelemetry library\nare the [Span\nContext](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/trace/api.md#spancontext)\nfor the currently active Span and the\n[Baggage](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/baggage/api.md)\n\nWhen a Context variable is not an explicit argument in the API macros or\nfunctions the Context from the [process\ndictionary](https://www.erlang.org/doc/reference_manual/processes.html#process-dictionary)\nis used. If no Context is found in the current process's pdict then one is\ncreated.\n\n##","ref":"readme.html#context"},{"type":"extras","title":"Starting and Ending Spans - Erlang/Elixir OpenTelemetry API","doc":"A Span represents a single operation in a Trace. It has a start and end time,\ncan have a single parent and one or more children. The easiest way to create\nSpans is to wrap the operation you want a Span to represent in the `with_span`\nmacro. The macro handles getting a\n[Tracer](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/trace/api.md#tracer)\nassociated with the OTP Application the module is in, starting the Span, setting\nit as the currently active Span in the Context stored in the process dictionary\nand ending the Span when the `Fun` or body of the Elixir macro finish, even if\nan exception is thrown -- however, the exception is not caught, so it does not\nchange how user code should deal with raised exceptions. After the Span is\nended the Context in the process dictionary is reset to its value before the\nnewly started Span was set as the active Span. This handling of the active Span\nin the process dictionary ensures proper lineage of Spans is kept when starting\nand ending child Spans.\n\n``` erlang\n?with_span(SpanName, StartOpts, Fun)\n```\n\n``` elixir\nOpenTelemetry.Tracer.with_span name, start_opts do\n    ...\nend\n```\n\n`StartOpts`/`start_opts` is a map of [Span creation options](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/trace/api.md#span-creation):\n\n- `kind`: \n[SpanKind](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/trace/api.md#spankind)\ndefines the relationship between the Span, its parents, and its children in a\nTrace. Possible values: `internal`, `server`, `client`, `producer` and\n`consumer`. Defaults to `internal` if not specified.\n- `attributes`: See\n  [Attributes](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/common/common.md#attributes)\n  for details about Attributes. Default is an empty list of attributes.\n- `links`:  List of [Links](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/overview.md#links-between-spans) to causally related Spans from the same or a different Trace.\n- `start_time`: The start time of the Span operation. Defaults to the current\n  time. The option should only be set if the start of the operation described by\n  the Span has already passed.\n\ncurrent_span_ctx(ctx)\n\nset_current_span(span_ctx)\n\nWhen using `start_span` instead of `with_span` there must be a corresponding\ncall to the [end Span\nAPI](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/trace/api.md#end)\nto signal that the operation described by the Span has ended. `end_span`\noptionally takes a timestamp to use as the end time of the Span.\n\n``` erlang\n?end_span()\n?end_span(Timestamp)\n```\n\n``` elixir\nOpenTelemetry.Tracer.end_span(timestamp \\\\ :undefined)\n```\n\n##","ref":"readme.html#starting-and-ending-spans"},{"type":"extras","title":"Sampling - Erlang/Elixir OpenTelemetry API","doc":"Sampling is performed at span creation time by the Sampler configured on the Tracer, see [Samplers](https://hexdocs.pm/opentelemetry/readme.html).\n\nTo pass attributes for use by the sampler, use the attributes field of `StartOpts`/`start_opts` \n\nexample:\n\n``` elixir\nOpenTelemetry.Tracer.start_span(span_name, %{attributes: %{my_attribute: \"my value\"}})\n```\n\n\n##","ref":"readme.html#sampling"},{"type":"extras","title":"Setting Attributes - Erlang/Elixir OpenTelemetry API","doc":"[Setting\nAttributes](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/trace/api.md#set-attributes)\ncan be done with a single key and value passed to `set_attribute` or through a\nmap of\n[Attributes](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/common/common.md#attributes)\nall at once. Setting an attribute with a key that already exists in the Span's\nmap of attributes will result in that key's value being overwritten.\n\n``` erlang\n?set_attribute(Key, Value)\n?set_attributes(Attributes)\n```\n\n``` elixir\nOpenTelemetry.Tracer.set_attribute(key, value)\nOpenTelemetry.Tracer.set_attributes(attributes)\n```\n\nBe aware that there are [configurable limits](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/common/common.md#attribute-limits) on the number and size of\nAttributes per Span.\n\n##","ref":"readme.html#setting-attributes"},{"type":"extras","title":"Adding Events - Erlang/Elixir OpenTelemetry API","doc":"[Adding\nEvents](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/trace/api.md#add-events)\ncan be done by passing the name of the event and the\n[Attributes](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/common/common.md#attributes)\nto associate with it or as a list of Events. Each Event in the list of Events is\na map containing the timestamp, name, and Attributes which can be created with\nthe function `event/2` and `event/3` in the `opentelemetry` and `OpenTelemetry`\nmodules.\n\n``` erlang\n?add_event(Name, Attributes)\n?add_events(Events)\n```\n\n``` elixir\nOpenTelemetry.Tracer.add_event(event, attributes)\nOpenTelemetry.Tracer.add_events(events)\n```\n\n##","ref":"readme.html#adding-events"},{"type":"extras","title":"Setting the Status - Erlang/Elixir OpenTelemetry API","doc":"[Set\nStatus](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/trace/api.md#set-status)\nwill override the default Span Status of `Unset`. A Status is a code (`ok`,\n`error` or `unset`) and, only if the code is `error`, an optional message string\nthat describes the error.\n\n``` erlang\n?set_status(Code, Message)\n```\n\n``` elixir\nOpenTelemetry.Tracer.set_status(code, message)\n```\n\n##","ref":"readme.html#setting-the-status"},{"type":"extras","title":"Update Span Name - Erlang/Elixir OpenTelemetry API","doc":"[Updating the Span\nname](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/trace/api.md#updatename)\ncan be done after starting the Span but must be done before the Span is end'ed.\n\n``` erlang\n?update_name(Name)\n```\n\n``` elixir\nOpenTelemetry.Tracer.update_name(name)\n```\n\n#","ref":"readme.html#update-span-name"},{"type":"extras","title":"Including the OpenTelemetry SDK - Erlang/Elixir OpenTelemetry API","doc":"When only the API is available at runtime a no-op Tracer is used and no Traces\nare exported. The [OpenTelemetry SDK](https://hex.pm/packages/opentelemetry)\nprovides the functionality of Tracers, Span Processors and Exporters and should\nbe included as part of a\n[Release](https://erlang.org/doc/design_principles/release_structure.html) and\nnot as a dependency of any individual Application.\n\n#","ref":"readme.html#including-the-opentelemetry-sdk"},{"type":"extras","title":"Exporters - Erlang/Elixir OpenTelemetry API","doc":"Included in the same [Github\nrepo](https://github.com/open-telemetry/opentelemetry-erlang) as the API and SDK are an exporter for the [OpenTelemetry Protocol\n(OTLP)](https://github.com/open-telemetry/opentelemetry-specification/blob/v1.8.0/specification/protocol/otlp.md)\nand [Zipkin](https://zipkin.io/):\n\n- [OpenTelemetry Protocol](https://hex.pm/packages/opentelemetry_exporter)\n- [Zipkin](https://hex.pm/packages/opentelemetry_zipkin)\n\n#","ref":"readme.html#exporters"},{"type":"extras","title":"Log Correlation - Erlang/Elixir OpenTelemetry API","doc":"When a Span is made active in a process, for example when the `with_span` macro\nis used, it is added to the [logger\nmetadata](https://www.erlang.org/doc/apps/kernel/logger_chapter.html). The\nmetadata is under the key `otel_span_ctx`. Example usage:\n\n``` erlang\n{kernel,\n  [{logger_level, debug},\n    {logger,\n     [{handler, default, logger_std_h,\n       #{formatter => {logger_formatter,\n                        #{template => [time, \" \", file, \":\", line, \" \", level, \": \",\n                                       {otel_trace_id, [\"trace_id=\",otel_trace_id,\" \"], []},\n                                       {otel_span_id, [\"span_id=\",otel_span_id,\" \"], []},\n                                       msg,\"\\n\"]}}}}]}]}\n```\n\n#","ref":"readme.html#log-correlation"},{"type":"extras","title":"Integrations - Erlang/Elixir OpenTelemetry API","doc":"Instrumentations of many popular Erlang and Elixir projects can be found in the\n[contrib repo](https://github.com/open-telemetry/opentelemetry-erlang-contrib)\nand on [hex.pm](https://hex.pm) under the [OpenTelemetry organization](https://hex.pm/orgs/opentelemetry).","ref":"readme.html#integrations"},{"type":"extras","title":"Contributing - Erlang/Elixir OpenTelemetry API","doc":"Read OpenTelemetry project [contributing\nguide](https://github.com/open-telemetry/community/blob/main/CONTRIBUTING.md)\nfor general information about the project.","ref":"readme.html#contributing"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright [yyyy] [name of copyright owner]\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"},{"type":"extras","title":"Versioning and Releasing","doc":"# Versioning and Releasing\n\n[OTP] Applications and the [OpenTelemetry Spec] itself use [semver v2].\n\nIn this document, references to OTP concepts are distinguished by capitalizing the word\n(for example Application and Release) while the generic term (like release) is\nlowercase.\n\n[OTP]: http://erlang.org/doc/system_architecture_intro/sys_arch_intro.html\n[OpenTelemetry Spec]: https://github.com/open-telemetry/opentelemetry-specification\n[semver v2]: https://semver.org/spec/v2.0.0.html","ref":"versioning.html"},{"type":"extras","title":"Module Prefix - Versioning and Releasing","doc":"The module prefix for all modules in any of these core Applications is\n`otel`. This means modules can move between Applications without their name\nchanging. Because of Erlang's flat namespace, there is no code for a user to change\nwhen an API graduates from experimental to stable, if the user was\nusing the latest version of the experimental API.\n\nThis also allows flexibility for modules that might be in the SDK but are found\nto be better placed in the API, or vice versa. This has happened a few times in\nthe pre-1.0 world as functionality was floating from SDK to API at times.","ref":"versioning.html#module-prefix"},{"type":"extras","title":"OTP Applications - Versioning and Releasing","doc":"#","ref":"versioning.html#otp-applications"},{"type":"extras","title":"Experimental API (`opentelemetry_api_experimental`) - Versioning and Releasing","doc":"The experimental package is where any API that is not stable when 1.0 is\nreleased [MUST] live. At this time (prior to 1.0) that means Metrics and Logging.\n\nThis package will always be 0.x because it is never stable and modules will be\nremoved when they are moved to the stable API package. Breaking changes,\nas well as non-trivial additions, to the experimental API will only result in a\nminor version bump.\n[MUST]: https://tools.ietf.org/html/rfc2119#section-1\n\n#","ref":"versioning.html#experimental-api-opentelemetry_api_experimental"},{"type":"extras","title":"API (`opentelemetry_api`) - Versioning and Releasing","doc":"The API package must provide semver-defined backwards-compatibility\nonce a major version (e.g. 1.0.0) is released. When a particular part of the API\nbecomes stable, its modules are moved from `opentelemetry_api_experimental` to\n`opentelemetry_api` and a new minor release of both is published.\n\nAt the release of version 1.0, the following signal APIs will be included\nin `opentelemetry_api`:\n\n* Tracing\n* Baggage\n* Context\n\n#","ref":"versioning.html#api-opentelemetry_api"},{"type":"extras","title":"Experimental SDK (`opentelemetry_sdk_experimental`) - Versioning and Releasing","doc":"The experimental SDK contains the implementations for the APIs in the\nexperimental API of the same minor version. For example, there may be\nmultiple patch-level releases (`v0.3.2`, `v0.3.3`) of the experimental\nSDK for each minor version of the experimental API (`v0.3.0`).\nAny setup for signals contained in the experimental SDK must be done on startup\nof the experimental SDK. For example, setting the default Meter would be done\nin `start/2` of `opentelemetry_sdk_experimental`.\n\n#","ref":"versioning.html#experimental-sdk-opentelemetry_sdk_experimental"},{"type":"extras","title":"SDK (`opentelemetry`) - Versioning and Releasing","doc":"Functionality is implemented in this Application and the API is dynamically\nconfigured to use a particular SDK -- at this time there is only 1 SDK\nimplementation, the default implementation.\n\nA goal is that the latest SDK can always be used with any version of the API, so\nthat a user can always pull the latest implementation into their final Release\nto run with any API versions that were used in instrumented Applications within the\nRelease.\n\n#","ref":"versioning.html#sdk-opentelemetry"},{"type":"extras","title":"OTLP Exporter (`opentelemetry_exporter`) - Versioning and Releasing","doc":"Exporter implementations are tied to the SDK's public API.","ref":"versioning.html#otlp-exporter-opentelemetry_exporter"},{"type":"extras","title":"Releases - Versioning and Releasing","doc":"#","ref":"versioning.html#releases"},{"type":"extras","title":"Experimental API - Versioning and Releasing","doc":"As noted in the previous section, `opentelemetry_api_experimental` is versioned\nseparately from the rest and will always remain 0.x.\n\n#","ref":"versioning.html#experimental-api"},{"type":"extras","title":"API - Versioning and Releasing","doc":"Additions to the API are released with minor version bumps.\n\n#","ref":"versioning.html#api"},{"type":"extras","title":"Experimental SDK - Versioning and Releasing","doc":"As noted in the previous section, `opentelemetry_sdk_experimental` is versioned\nseparately from the rest, but in lockstep with `opentelemetry_api_experimental`,\nand will always remain 0.x.\n\n#","ref":"versioning.html#experimental-sdk"},{"type":"extras","title":"SDK - Versioning and Releasing","doc":"Additions to the SDK are released with minor version bumps.","ref":"versioning.html#sdk"},{"type":"extras","title":"Deprecation - Versioning and Releasing","doc":"Code is only marked as deprecated when the replacement is stable.\n\nUnlikely example: There is a Tracing v2 spec defined. The module will be named\n`otel_trace2` and the functions in `otel_trace` marked as deprecated.\n\nDeprecated functions must be marked with `-deprecated` in the module so that\n`xref` provides a warning about usage to the user.","ref":"versioning.html#deprecation"},{"type":"extras","title":"Removal - Versioning and Releasing","doc":"A major version bump is required to remove a signal or module.\n\nIn the unlikely example mentioned in the Deprecation section, this step would mean removal of the\noriginal module (`otel_trace`) and a major version bump release.","ref":"versioning.html#removal"},{"type":"extras","title":"Examples - Versioning and Releasing","doc":"Purely for illustration purposes, not intended to represent actual releases:\n\n- v1.0.0 release:\n   - `opentelemetry_api` 1.0.0\n     - Contains APIs for tracing, baggage, propagators\n   - `opentelemetry_api_experimental` 0.2.0\n     - Contains APIs for metrics\n   - `opentelemetry_sdk` 1.0.0\n   - `opentelemetry_sdk_experimental` 0.2.0\n- v1.15.0 release (with metrics)\n   - `opentelemetry_api` 1.15.0\n     - Contains APIs for tracing, baggage, propagators, metrics\n   - `opentelemetry_api_experimental` 0.42.0\n     - No longer contains APIs for metrics\n   - `opentelemetry_sdk` 1.15.0\n   - `opentelemetry_sdk_experimental` 0.42.0","ref":"versioning.html#examples"}],"producer":{"name":"ex_doc","version":[48,46,51,49,46,50]},"content_type":"text/plain"}